==> beagle-0.1.0.tar.gz: beagle-0.1.0/libbeagle/beagle/beagle-cancelled-response.h <==
/*
 * beagle-cancelled-response.h
 *
 * Copyright (C) 2005 Novell, Inc.
 *
 */

/*
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef __BEAGLE_CANCELLED_RESPONSE_H
#define __BEAGLE_CANCELLED_RESPONSE_H

#include <glib-object.h>
#include "beagle-response.h"

#define BEAGLE_TYPE_CANCELLED_RESPONSE            (beagle_cancelled_response_get_type ())
#define BEAGLE_CANCELLED_RESPONSE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), BEAGLE_TYPE_CANCELLED_RESPONSE, BeagleCancelledResponse))
#define BEAGLE_CANCELLED_RESPONSE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), BEAGLE_TYPE_CANCELLED_RESPONSE, BeagleCancelledResponseClass))
#define BEAGLE_IS_CANCELLED_RESPONSE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BEAGLE_TYPE_CANCELLED_RESPONSE))
#define BEAGLE_IS_CANCELLED_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BEAGLE_TYPE_CANCELLED_RESPONSE))
#define BEAGLE_CANCELLED_RESPONSE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), BEAGLE_TYPE_CANCELLED_RESPONSE, BeagleCancelledResponseClass))

typedef struct {
	BeagleResponse parent;
} BeagleCancelledResponse;

typedef struct {
	BeagleResponseClass parent_class;
} BeagleCancelledResponseClass;

GType    beagle_cancelled_response_get_type (void);

#endif /* __BEAGLE_CANCELLED_RESPONSE_H */

==> beagle-0.1.3.tar.gz: beagle-0.1.3/libbeagle/beagle/beagle-cancelled-response.h <==
/*
 * beagle-cancelled-response.h
 *
 * Copyright (C) 2005 Novell, Inc.
 *
 */

/*
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

#ifndef __BEAGLE_CANCELLED_RESPONSE_H
#define __BEAGLE_CANCELLED_RESPONSE_H

#include <glib-object.h>
#include "beagle-response.h"

#define BEAGLE_TYPE_CANCELLED_RESPONSE            (beagle_cancelled_response_get_type ())
#define BEAGLE_CANCELLED_RESPONSE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), BEAGLE_TYPE_CANCELLED_RESPONSE, BeagleCancelledResponse))
#define BEAGLE_CANCELLED_RESPONSE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), BEAGLE_TYPE_CANCELLED_RESPONSE, BeagleCancelledResponseClass))
#define BEAGLE_IS_CANCELLED_RESPONSE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BEAGLE_TYPE_CANCELLED_RESPONSE))
#define BEAGLE_IS_CANCELLED_RESPONSE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BEAGLE_TYPE_CANCELLED_RESPONSE))
#define BEAGLE_CANCELLED_RESPONSE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), BEAGLE_TYPE_CANCELLED_RESPONSE, BeagleCancelledResponseClass))

typedef struct _BeagleCancelledResponse      BeagleCancelledResponse;
typedef struct _BeagleCancelledResponseClass BeagleCancelledResponseClass;

struct _BeagleCancelledResponse {
	BeagleResponse parent;
};

struct _BeagleCancelledResponseClass {
	BeagleResponseClass parent_class;
};

GType    beagle_cancelled_response_get_type (void);

#endif /* __BEAGLE_CANCELLED_RESPONSE_H */
